@@ -1,6 +1,6 @@
 use musli::{Decode, Encode};
+use musli_wire::tag::{Kind, Tag};
 use musli_wire::test::Typed;
-use musli_wire::types::TypeTag;
 
 #[derive(Debug, PartialEq, Encode, Decode)]
 #[musli(default_field_tag = "name")]
@@ -34,22 +34,28 @@ fn struct_named_fields() {
     assert_eq!(
         unpacked,
         Unpacked {
-            field_count: Typed::new(TypeTag::PairSequence, 2),
-            field1_name: Typed::new(TypeTag::Prefixed, String::from("string")),
-            field1_value: Typed::new(TypeTag::Prefixed, String::from("foo")),
-            field2_name: Typed::new(TypeTag::Prefixed, String::from("number")),
-            field2_value: Typed::new(TypeTag::Continuation, 42),
+            field_count: Tag::new(Kind::Sequence, 4),
+            field1_name: Typed::new(
+                Tag::new(Kind::Prefix, 6),
+                [b's', b't', b'r', b'i', b'n', b'g']
+            ),
+            field1_value: Typed::new(Tag::new(Kind::Prefix, 3), [b'f', b'o', b'o']),
+            field2_name: Typed::new(
+                Tag::new(Kind::Prefix, 6),
+                [b'n', b'u', b'm', b'b', b'e', b'r']
+            ),
+            field2_value: Tag::new(Kind::Continuation, 42),
         }
     );
 
     #[derive(Debug, PartialEq, Decode)]
     #[musli(packed)]
     pub struct Unpacked {
-        field_count: Typed<u8>,
-        field1_name: Typed<String>,
-        field1_value: Typed<String>,
-        field2_name: Typed<String>,
-        field2_value: Typed<u32>,
+        field_count: Tag,
+        field1_name: Typed<[u8; 6]>,
+        field1_value: Typed<[u8; 3]>,
+        field2_name: Typed<[u8; 6]>,
+        field2_value: Tag,
     }
 }
 
@@ -71,21 +77,21 @@ fn struct_indexed_fields() {
     assert_eq!(
         unpacked,
         Unpacked {
-            field_count: Typed::new(TypeTag::PairSequence, 2),
-            field1_index: Typed::new(TypeTag::Continuation, 0),
-            field1_value: Typed::new(TypeTag::Prefixed, String::from("foo")),
-            field2_index: Typed::new(TypeTag::Continuation, 1),
-            field2_value: Typed::new(TypeTag::Continuation, 42),
+            field_count: Tag::new(Kind::Sequence, 4),
+            field1_index: Tag::new(Kind::Continuation, 0),
+            field1_value: Typed::new(Tag::new(Kind::Prefix, 3), [b'f', b'o', b'o']),
+            field2_index: Tag::new(Kind::Continuation, 1),
+            field2_value: Tag::new(Kind::Continuation, 42),
         }
     );
 
     #[derive(Debug, PartialEq, Decode)]
     #[musli(packed)]
     pub struct Unpacked {
-        field_count: Typed<u8>,
-        field1_index: Typed<u8>,
-        field1_value: Typed<String>,
-        field2_index: Typed<u8>,
-        field2_value: Typed<u32>,
+        field_count: Tag,
+        field1_index: Tag,
+        field1_value: Typed<[u8; 3]>,
+        field2_index: Tag,
+        field2_value: Tag,
     }
 }
